Alphabetical PtYx tags reference — PtYx 19.8 documentation

# Alphabetical PtYx tags reference

## ADD tag

## ASSERT tag

## CALC tag

## COMMENT tag

## DEBUG tag

## ELIF tag

## ELSE tag

## EQUAL tag

## EVAL tag

## FREEZE_RANDOM_STATE tag

## GCALC tag

## GEO tag

## IF tag

## IFNUM tag

## ITEM tag

## MACRO tag

## MUL tag

## NEW_MACRO tag

## PICK tag

## PYTHON tag

## RAND tag

## ROOT tag

## SEED tag

## SHUFFLE tag

## SIGN tag

## SUB tag

## SYMPY tag

## TABSIGN tag

## TABVAR tag

## TEST tag